@@ -1,5 +1,5 @@
 from os import environ
-from tokenize import maybe
+import concurrent.futures
 from typing import Optional, Any, Dict, List, TypedDict
 import logging
 import json
@@ -27,22 +27,17 @@ class PrintNannyConfig(TypedDict):
     config: Optional[Dict[str, Any]]
 
 
-async def deserialize_pi(pi_dict) -> Pi:
-    async with printnanny_api_client.ApiClient() as client:
-        return client._ApiClient__deserialize(pi_dict, Pi)
+def deserialize_pi(pi_dict) -> Pi:
+    client = printnanny_api_client.api_client.ApiClient()
+    return client._ApiClient__deserialize(pi_dict, Pi)  # type: ignore
 
 
 def load_pi_model(pi_dict: Dict[str, Any]) -> Pi:
-    try:
-        loop = asyncio.get_running_loop()
-    except RuntimeError:
-        loop = asyncio.new_event_loop()
-        asyncio.set_event_loop(loop)
-    coroutine = deserialize_pi(pi_dict)
-    result = loop.run_until_complete(coroutine)
+    result = deserialize_pi(pi_dict)
+
     global PRINTNANNY_PI
     PRINTNANNY_PI = result
-    return result
+    return PRINTNANNY_PI
 
 
 def load_printnanny_config() -> PrintNannyConfig:
